@@ -80,7 +80,7 @@ class Application(IUriHandler, ITerminal, IErrorListener):
 
     @author: Vaadin Ltd.
     @author: Richard Lincoln
-    @version: 1.0.1
+    @version: 1.0.3
     """
 
     #: The default SystemMessages (read-only). Change by overriding
@@ -844,7 +844,7 @@ class Application(IUriHandler, ITerminal, IErrorListener):
                 owner.setComponentError( SysError(t) )
 
         # also print the error on console
-        logger.critical('ITerminal error: ' + str(t))
+        logger.exception('ITerminal error: ' + str(t))
 
         exc_type, _, exc_traceback = sys.exc_info()
         traceback.print_exception(exc_type, t,
@@ -904,7 +904,7 @@ class UserChangeEvent(EventObject):
     Application user change event sent when the setUser is called to change
     the current user of the application.
 
-    @version: 1.0.1
+    @version: 1.0.3
     """
 
     def __init__(self, source, newUser, prevUser):
@@ -955,7 +955,7 @@ class IUserChangeListener(IEventListener):
     """The C{UserChangeListener} interface for listening application
     user changes.
 
-    @version: 1.0.1
+    @version: 1.0.3
     """
 
     def applicationUserChanged(self, event):
