@@ -90,7 +90,7 @@ class AbstractApplicationServlet(PasteWsgiServlet, Constants):
 
     @author: Vaadin Ltd.
     @author: Richard Lincoln
-    @version: 1.0.1
+    @version: 1.0.3
     """
 
     #: The version number of this release. For example "6.2.0". Always in the
@@ -112,10 +112,10 @@ class AbstractApplicationServlet(PasteWsgiServlet, Constants):
     VERSION_BUILD = None
 
     #: Initialize version numbers from string replaced by build-script.
-    if '1.0.1' == '@' + 'VERSION' + '@':
+    if '1.0.3' == '@' + 'VERSION' + '@':
         VERSION = '9.9.9.INTERNAL-DEBUG-BUILD'
     else:
-        VERSION = '1.0.1'
+        VERSION = '1.0.3'
 
     digits = VERSION.split('.', 4)
     VERSION_MAJOR = int(digits[0])
@@ -244,8 +244,9 @@ class AbstractApplicationServlet(PasteWsgiServlet, Constants):
         that of the server.
         """
         if not (self.VERSION == self.getParameter(request, 'wsver', '')):
-            logger.warning(self.WIDGETSET_MISMATCH_INFO %
-                    (self.VERSION, self.getParameter(request, 'wsver', '')))
+#            logger.warning(self.WIDGETSET_MISMATCH_INFO %
+#                    (self.VERSION, self.getParameter(request, 'wsver', '')))
+            pass  # FIXME: implement Python client side
 
 
     def checkProductionMode(self):
