@@ -1026,12 +1026,13 @@ class AbstractCommunicationManager(IPaintable, IRepaintRequestListener):
                 if (variable[self._VAR_NAME] == 'close'
                         and variable[self._VAR_VALUE] == 'true'):
                     # Silently ignore this
+                    i += 1
                     continue
 
                 # Ignore variable change
                 msg = 'Warning: Ignoring variable change for '
                 if owner is not None:
-                    msg += 'disabled component ' + owner.__class__
+                    msg += 'disabled component ' + str(owner.__class__)
                     caption = owner.getCaption()
                     if caption is not None:
                         msg += ', caption=' + caption
@@ -1041,7 +1042,6 @@ class AbstractCommunicationManager(IPaintable, IRepaintRequestListener):
                     success = False
 
                 logger.warning(msg)
-                continue
 
             i += 1
 
